@keyframes ripple {
  to {
    background-size: 1000% 1000%;
  }
}

@keyframes ripple-on-slider {
  to {
    background-size: auto, 1000% 1000%;
  }
}

@keyframes ripple-on-headerbar {
  from {
    background-image: radial-gradient(circle, #1967d2 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle, #1967d2 100%, transparent 100%);
  }
}

popover.emoji-completion > contents emoji, popover.emoji-completion > contents emoji-completion-row, popover.emoji-picker > contents emoji, calendar > grid > label.day-number, expander, listview > row, row.activatable, check,
radio, notebook > header > tabs > tab, notebook > header > tabs > arrow, menubar > item, modelbutton.flat,
button, spinbutton:not(.vertical) > image,
entry > image, gridview > child, flowbox > flowboxchild {
  transition-property: all, border-image, background-size, background-image;
  transition-duration: 75ms, 225ms, 300ms, 1200ms;
  transition-timing-function: cubic-bezier(0, 0, 0.2, 1);
  background-image: radial-gradient(circle, transparent 10%, transparent 10%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
}

popover.emoji-completion > contents emoji:active, popover.emoji-completion > contents emoji-completion-row:active, popover.emoji-picker > contents emoji:active, calendar > grid > label.day-number:active, expander:active, listview > row:active, row.activatable:active, check:active,
radio:active, notebook > header > tabs > tab:active, notebook > header > tabs > arrow:active, menubar > item:active, modelbutton.flat:active,
button:active, spinbutton:not(.vertical) > image:active,
entry > image:active, gridview > child:active, flowbox > flowboxchild:active {
  transition-duration: 75ms, 225ms, 0ms, 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-size: 0% 0%;
}

/**
 * Base States
 */
.background {
  background-color: #f9f9f9;
  color: rgba(0, 0, 0, 0.87);
}

dnd {
  color: rgba(0, 0, 0, 0.87);
}

.normal-icons {
  -gtk-icon-size: 16px;
}

.large-icons {
  -gtk-icon-size: 32px;
}

image:disabled {
  -gtk-icon-filter: opacity(0.5);
}

.view > .cell:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

.view:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.view:selected {
  background-color: rgba(25, 103, 210, 0.24);
}

.view > .cell:selected:hover {
  background-color: rgba(25, 103, 210, 0.3008);
}

textview {
  caret-color: #1967d2;
}

textview > text > selection {
  background-color: rgba(25, 103, 210, 0.24);
}

textview > border {
  color: rgba(0, 0, 0, 0.6);
}

iconview > .cell {
  border-radius: 4px;
}

iconview > dndtarget:drop(active) {
  box-shadow: inset 0 0 0 2px #1967d2;
}

rubberband, columnview.view > rubberband,
treeview.view > rubberband {
  border: 1px solid #1967d2;
  background-color: rgba(25, 103, 210, 0.24);
}

flowbox {
  padding: 4px;
  border-spacing: 4px;
}

flowbox > flowboxchild {
  padding: 4px;
  border-radius: 4px;
}

flowbox > flowboxchild:drop(active), flowbox > flowboxchild:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

flowbox > flowboxchild:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

flowbox > flowboxchild:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

flowbox > flowboxchild:selected {
  background-color: rgba(25, 103, 210, 0.24);
  background-color: rgba(25, 103, 210, 0.24);
}

flowbox > flowboxchild:selected:drop(active), flowbox > flowboxchild:selected:hover {
  background-color: rgba(25, 103, 210, 0.3008);
}

flowbox > flowboxchild:selected:focus {
  background-color: rgba(25, 103, 210, 0.3312);
}

flowbox > flowboxchild:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

gridview {
  padding: 4px;
  border-spacing: 4px;
}

gridview > child {
  padding: 4px;
  border-radius: 4px;
}

gridview > child:drop(active), gridview > child:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

gridview > child:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

gridview > child:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

gridview > child:selected {
  background-color: rgba(25, 103, 210, 0.24);
  background-color: rgba(25, 103, 210, 0.24);
}

gridview > child:selected:drop(active), gridview > child:selected:hover {
  background-color: rgba(25, 103, 210, 0.3008);
}

gridview > child:selected:focus {
  background-color: rgba(25, 103, 210, 0.3312);
}

gridview > child:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

coverflow > cover {
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

.content-view .tile:selected {
  background-color: transparent;
}

label {
  caret-color: #1967d2;
}

label.separator {
  color: rgba(0, 0, 0, 0.6);
}

label.error {
  color: #d93025;
}

label > selection {
  background-color: rgba(25, 103, 210, 0.24);
}

label:disabled {
  color: rgba(0, 0, 0, 0.38);
}

headerbar label:disabled, modelbutton label:disabled, tab label:disabled, button label:disabled {
  color: inherit;
}

label.osd {
  border-radius: 4px;
  background-color: rgba(97, 97, 97, 0.9);
  color: #fff;
}

.dim-label {
  color: rgba(0, 0, 0, 0.6);
}

window.assistant .sidebar {
  padding: 4px 0;
}

window.assistant .sidebar > label {
  min-height: 36px;
  padding: 0 12px;
  color: rgba(0, 0, 0, 0.38);
  font-weight: 500;
}

window.assistant .sidebar > label.highlight {
  color: rgba(0, 0, 0, 0.87);
}

window.aboutdialog > box > box > image.large-icons {
  -gtk-icon-size: 128px;
}

/**
 * Spinner Animation
 */
@keyframes spin {
  to {
    transform: rotate(1turn);
  }
}

spinner {
  opacity: 0;
  color: #1967d2;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  transition: opacity 300ms cubic-bezier(0, 0, 0.2, 1);
  animation: spin 1s linear infinite;
}

spinner:checked {
  opacity: 1;
}

spinner:disabled {
  color: rgba(0, 0, 0, 0.26);
}

/**
 * General Typography
 */
.large-title {
  font-weight: 400;
  font-size: 36pt;
}

.title-1 {
  font-weight: 400;
  font-size: 25.5pt;
  letter-spacing: 0.1875pt;
}

.title-2 {
  font-weight: 400;
  font-size: 18pt;
}

.title-3 {
  font-weight: 500;
  font-size: 15pt;
  letter-spacing: 0.1125pt;
}

.title-4 {
  font-weight: 400;
  font-size: 12pt;
  letter-spacing: 0.375pt;
}

.heading {
  font-weight: 500;
  font-size: 1em;
}

.body {
  font-weight: 400;
  font-size: 1em;
}

.caption-heading {
  font-weight: 500;
  font-size: 9pt;
  letter-spacing: 1.125pt;
}

.caption {
  font-weight: 400;
  font-size: 9pt;
  letter-spacing: 0.3pt;
}

/**
 * Text Entries
 */
spinbutton:not(.vertical),
entry {
  min-height: 36px;
  padding: 0 8px;
  border-spacing: 6px;
  border-radius: 4px 4px 0 0;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 0%, transparent 0%) 2/0 0 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
  caret-color: #1967d2;
}

spinbutton:hover:not(.vertical), spinbutton:drop(active):not(.vertical),
entry:hover,
entry:drop(active) {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.0784);
}

spinbutton:focus-within:not(.vertical),
entry:focus-within {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 100%, transparent 100%) 2/0 0 2px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.1168);
}

spinbutton:focus-within:not(.vertical) > text > placeholder,
entry:focus-within > text > placeholder {
  opacity: 0;
}

spinbutton:disabled:not(.vertical),
entry:disabled {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.flat:not(.vertical),
entry.flat {
  min-height: 0;
  padding: 2px;
  border-radius: 0;
  background-color: transparent;
}

spinbutton:not(.vertical) > text > placeholder,
entry > text > placeholder {
  color: rgba(0, 0, 0, 0.6);
}

spinbutton:not(.vertical) > text > selection,
entry > text > selection {
  background-color: rgba(25, 103, 210, 0.24);
}

spinbutton:not(.vertical) > text > block-cursor,
entry > text > block-cursor {
  background-color: #1967d2;
  color: #fff;
}

spinbutton:not(.vertical) > image,
entry > image {
  min-width: 24px;
  min-height: 24px;
  border-radius: 9999px;
  color: rgba(0, 0, 0, 0.6);
  margin-top: 6px;
  margin-bottom: 6px;
}

spinbutton:not(.vertical) > image:drop(active), spinbutton:not(.vertical) > image:hover,
entry > image:drop(active),
entry > image:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

spinbutton:not(.vertical) > image:focus,
entry > image:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

spinbutton:not(.vertical) > image:active,
entry > image:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

spinbutton:not(.vertical) > image:disabled,
entry > image:disabled {
  color: rgba(0, 0, 0, 0.38);
}

spinbutton:not(.vertical) > image.left,
entry > image.left {
  margin-left: -2px;
}

spinbutton:not(.vertical) > image.right,
entry > image.right {
  margin-right: -2px;
}

spinbutton.error:not(.vertical),
entry.error {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #d93025 0%, transparent 0%) 2/0 0 0px;
  box-shadow: inset 0 -1px #d93025;
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
  caret-color: #d93025;
}

spinbutton.error:focus-within:not(.vertical),
entry.error:focus-within {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #d93025 100%, transparent 100%) 2/0 0 2px;
  box-shadow: inset 0 -1px #d93025;
  background-color: rgba(0, 0, 0, 0.1168);
}

spinbutton.error:disabled:not(.vertical),
entry.error:disabled {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.warning:not(.vertical),
entry.warning {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #f9ab00 0%, transparent 0%) 2/0 0 0px;
  box-shadow: inset 0 -1px #f9ab00;
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
  caret-color: #f9ab00;
}

spinbutton.warning:focus-within:not(.vertical),
entry.warning:focus-within {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #f9ab00 100%, transparent 100%) 2/0 0 2px;
  box-shadow: inset 0 -1px #f9ab00;
  background-color: rgba(0, 0, 0, 0.1168);
}

spinbutton.warning:disabled:not(.vertical),
entry.warning:disabled {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton:not(.vertical) > progress > trough > progress,
entry > progress > trough > progress {
  margin: 0 -8px;
  margin-bottom: -4px;
  border-bottom: 2px solid #1967d2;
  background-color: transparent;
}

spinbutton.vertical > text {
  border-radius: 4px;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
  caret-color: #1967d2;
}

spinbutton.vertical > text:focus-within {
  border-image: none;
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 8px 0 rgba(0, 0, 0, 0.12);
}

spinbutton.vertical > text:drop(active) {
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 8px 0 rgba(0, 0, 0, 0.12);
}

spinbutton.vertical > text:disabled {
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical > text.error {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #d93025;
  color: #fff;
  caret-color: #fff;
}

spinbutton.vertical > text.error:focus-within {
  border-image: none;
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 8px 0 rgba(0, 0, 0, 0.12);
}

spinbutton.vertical > text.error:disabled {
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical > text.error image {
  color: rgba(255, 255, 255, 0.7);
}

spinbutton.vertical > text.error image:hover, spinbutton.vertical > text.error image:active {
  color: #fff;
}

spinbutton.vertical > text.error image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

spinbutton.vertical > text.warning {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #f9ab00;
  color: #000;
  caret-color: #000;
}

spinbutton.vertical > text.warning:focus-within {
  border-image: none;
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 8px 0 rgba(0, 0, 0, 0.12);
}

spinbutton.vertical > text.warning:disabled {
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical > text.warning image {
  color: rgba(0, 0, 0, 0.7);
}

spinbutton.vertical > text.warning image:hover, spinbutton.vertical > text.warning image:active {
  color: #000;
}

spinbutton.vertical > text.warning image:disabled {
  color: rgba(0, 0, 0, 0.5);
}

treeview entry, treeview entry.flat {
  background-color: #fff;
}

treeview entry, treeview entry:focus-within, treeview entry.flat, treeview entry.flat:focus-within {
  border-image: none;
  box-shadow: none;
}

.entry-tag {
  margin: 2px;
  border-radius: 9999px;
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.87);
}

.entry-tag:hover {
  background-image: image(rgba(0, 0, 0, 0.08));
}

:dir(ltr) .entry-tag {
  margin-left: 4px;
  margin-right: 0;
  padding-left: 12px;
  padding-right: 8px;
}

:dir(rtl) .entry-tag {
  margin-left: 0;
  margin-right: 4px;
  padding-left: 8px;
  padding-right: 12px;
}

.entry-tag.button {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
}

/**
 * Buttons
 */
@keyframes needs-attention {
  from {
    background-image: radial-gradient(farthest-side, #1967d2 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(farthest-side, #1967d2 100%, transparent 100%);
  }
}


button {
  min-height: 24px;
  min-width: 16px;
  padding: 6px 10px;
  border-radius: 4px;
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
  font-weight: 500;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
}


button:drop(active),
button:hover {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: whitesmoke;
}


button:focus {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #ebebeb;
}


button:active {
  box-shadow: 0 5px 5px -3px rgba(0, 0, 0, 0.2), 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 2px rgba(0, 0, 0, 0.12);
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}


button:disabled {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.38);
}


button:checked {
  color: #1967d2;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #dae7f8;
}


button:checked:drop(active),
button:checked:hover {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #cbddf5;
}


button:checked:focus {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #c3d8f3;
}


button:checked:active {
  box-shadow: 0 5px 5px -3px rgba(0, 0, 0, 0.2), 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 2px rgba(0, 0, 0, 0.12);
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}


button:checked:disabled {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.1904);
  color: rgba(0, 0, 0, 0.38);
}


button.text-button {
  min-width: 32px;
  padding-left: 16px;
  padding-right: 16px;
}


button.image-button {
  min-width: 24px;
  padding: 6px;
  border-radius: 9999px;
}


button.text-button.image-button {
  min-width: 32px;
  padding-left: 16px;
  padding-right: 16px;
  border-radius: 4px;
}


button.text-button.image-button image:first-child {
  margin-left: -4px;
  margin-right: 8px;
}


button.text-button.image-button image:last-child {
  margin-left: 8px;
  margin-right: -4px;
}

frame button,
.frame button, popover button {
  background-color: transparent;
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.26);
  background-color: transparent;
}

frame button:drop(active),
.frame button:drop(active), popover button:drop(active), frame button:hover,
.frame button:hover, popover button:hover {
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.04);
}

frame button:focus,
.frame button:focus, popover button:focus {
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.08);
}

frame button:active,
.frame button:active, popover button:active {
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.26);
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

button.sidebar-button,
pathbar.linked:not(.vertical) > button, spinbutton.vertical button, spinbutton:not(.vertical) > button, combobox > .linked:not(.vertical) > button:not(:only-child), infobar.info > revealer > box button, infobar.question > revealer > box button, filechooser #pathbarbox > stack > box > button, window.dialog.message .dialog-action-area > button, .app-notification button, actionbar > revealer > box button:not(.suggested-action):not(.destructive-action), popover.menu button.model, .titlebar button:not(.suggested-action):not(.destructive-action), .toolbar button,
button.flat {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
  background-color: transparent;
}

button.sidebar-button:drop(active),
pathbar.linked:not(.vertical) > button:drop(active), spinbutton.vertical button:drop(active), spinbutton:not(.vertical) > button:drop(active), combobox > .linked:not(.vertical) > button:drop(active):not(:only-child), infobar.info > revealer > box button:drop(active), infobar.question > revealer > box button:drop(active), filechooser #pathbarbox > stack > box > button:drop(active), window.dialog.message .dialog-action-area > button:drop(active), .app-notification button:drop(active), actionbar > revealer > box button:drop(active):not(.suggested-action):not(.destructive-action), popover.menu button.model:drop(active), .titlebar button:drop(active):not(.suggested-action):not(.destructive-action), .toolbar button:drop(active),
button.flat:drop(active), button.sidebar-button:hover,
pathbar.linked:not(.vertical) > button:hover, spinbutton.vertical button:hover, spinbutton:not(.vertical) > button:hover, combobox > .linked:not(.vertical) > button:hover:not(:only-child), infobar.info > revealer > box button:hover, infobar.question > revealer > box button:hover, filechooser #pathbarbox > stack > box > button:hover, window.dialog.message .dialog-action-area > button:hover, .app-notification button:hover, actionbar > revealer > box button:hover:not(.suggested-action):not(.destructive-action), popover.menu button.model:hover, .titlebar button:hover:not(.suggested-action):not(.destructive-action), .toolbar button:hover,
button.flat:hover {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
}

button.sidebar-button:focus,
pathbar.linked:not(.vertical) > button:focus, spinbutton.vertical button:focus, spinbutton:not(.vertical) > button:focus, combobox > .linked:not(.vertical) > button:focus:not(:only-child), infobar.info > revealer > box button:focus, infobar.question > revealer > box button:focus, filechooser #pathbarbox > stack > box > button:focus, window.dialog.message .dialog-action-area > button:focus, .app-notification button:focus, actionbar > revealer > box button:focus:not(.suggested-action):not(.destructive-action), popover.menu button.model:focus, .titlebar button:focus:not(.suggested-action):not(.destructive-action), .toolbar button:focus,
button.flat:focus {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
}

button.sidebar-button:active,
pathbar.linked:not(.vertical) > button:active, spinbutton.vertical button:active, spinbutton:not(.vertical) > button:active, combobox > .linked:not(.vertical) > button:active:not(:only-child), infobar.info > revealer > box button:active, infobar.question > revealer > box button:active, filechooser #pathbarbox > stack > box > button:active, window.dialog.message .dialog-action-area > button:active, .app-notification button:active, actionbar > revealer > box button:active:not(.suggested-action):not(.destructive-action), popover.menu button.model:active, .titlebar button:active:not(.suggested-action):not(.destructive-action), .toolbar button:active,
button.flat:active {
  box-shadow: none;
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

button.sidebar-button:disabled,
pathbar.linked:not(.vertical) > button:disabled, spinbutton.vertical button:disabled, spinbutton:not(.vertical) > button:disabled, combobox > .linked:not(.vertical) > button:disabled:not(:only-child), infobar.info > revealer > box button:disabled, infobar.question > revealer > box button:disabled, filechooser #pathbarbox > stack > box > button:disabled, window.dialog.message .dialog-action-area > button:disabled, .app-notification button:disabled, actionbar > revealer > box button:disabled:not(.suggested-action):not(.destructive-action), popover.menu button.model:disabled, .titlebar button:disabled:not(.suggested-action):not(.destructive-action), .toolbar button:disabled,
button.flat:disabled {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

combobox > .linked:not(.vertical) > button:checked:not(:only-child), infobar.info > revealer > box button:checked, infobar.question > revealer > box button:checked, filechooser #pathbarbox > stack > box > button:checked, window.dialog.message .dialog-action-area > button:checked, .app-notification button:checked, actionbar > revealer > box button:checked:not(.suggested-action):not(.destructive-action), popover.menu button.model:checked, .titlebar button:checked:not(.suggested-action):not(.destructive-action), .toolbar button:checked,
button.flat:checked {
  color: #1967d2;
  box-shadow: none;
  background-color: rgba(25, 103, 210, 0.16);
}

combobox > .linked:not(.vertical) > button:checked:drop(active):not(:only-child), infobar.info > revealer > box button:checked:drop(active), infobar.question > revealer > box button:checked:drop(active), filechooser #pathbarbox > stack > box > button:checked:drop(active), window.dialog.message .dialog-action-area > button:checked:drop(active), .app-notification button:checked:drop(active), actionbar > revealer > box button:checked:drop(active):not(.suggested-action):not(.destructive-action), popover.menu button.model:checked:drop(active), .titlebar button:checked:drop(active):not(.suggested-action):not(.destructive-action), .toolbar button:checked:drop(active),
button.flat:checked:drop(active), combobox > .linked:not(.vertical) > button:checked:hover:not(:only-child), infobar.info > revealer > box button:checked:hover, infobar.question > revealer > box button:checked:hover, filechooser #pathbarbox > stack > box > button:checked:hover, window.dialog.message .dialog-action-area > button:checked:hover, .app-notification button:checked:hover, actionbar > revealer > box button:checked:hover:not(.suggested-action):not(.destructive-action), popover.menu button.model:checked:hover, .titlebar button:checked:hover:not(.suggested-action):not(.destructive-action), .toolbar button:checked:hover,
button.flat:checked:hover {
  box-shadow: none;
  background-color: rgba(25, 103, 210, 0.2608);
}

combobox > .linked:not(.vertical) > button:checked:focus:not(:only-child), infobar.info > revealer > box button:checked:focus, infobar.question > revealer > box button:checked:focus, filechooser #pathbarbox > stack > box > button:checked:focus, window.dialog.message .dialog-action-area > button:checked:focus, .app-notification button:checked:focus, actionbar > revealer > box button:checked:focus:not(.suggested-action):not(.destructive-action), popover.menu button.model:checked:focus, .titlebar button:checked:focus:not(.suggested-action):not(.destructive-action), .toolbar button:checked:focus,
button.flat:checked:focus {
  box-shadow: none;
  background-color: rgba(25, 103, 210, 0.2608);
}

combobox > .linked:not(.vertical) > button:checked:active:not(:only-child), infobar.info > revealer > box button:checked:active, infobar.question > revealer > box button:checked:active, filechooser #pathbarbox > stack > box > button:checked:active, window.dialog.message .dialog-action-area > button:checked:active, .app-notification button:checked:active, actionbar > revealer > box button:checked:active:not(.suggested-action):not(.destructive-action), popover.menu button.model:checked:active, .titlebar button:checked:active:not(.suggested-action):not(.destructive-action), .toolbar button:checked:active,
button.flat:checked:active {
  box-shadow: none;
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

combobox > .linked:not(.vertical) > button:checked:disabled:not(:only-child), infobar.info > revealer > box button:checked:disabled, infobar.question > revealer > box button:checked:disabled, filechooser #pathbarbox > stack > box > button:checked:disabled, window.dialog.message .dialog-action-area > button:checked:disabled, .app-notification button:checked:disabled, actionbar > revealer > box button:checked:disabled:not(.suggested-action):not(.destructive-action), popover.menu button.model:checked:disabled, .titlebar button:checked:disabled:not(.suggested-action):not(.destructive-action), .toolbar button:checked:disabled,
button.flat:checked:disabled {
  color: rgba(0, 0, 0, 0.38);
}

infobar.info > revealer > box button.text-button, infobar.question > revealer > box button.text-button, filechooser #pathbarbox > stack > box > button.text-button, window.dialog.message .dialog-action-area > button.text-button, .app-notification button.text-button, actionbar > revealer > box button.text-button:not(.suggested-action):not(.destructive-action), popover.menu button.text-button.model, .titlebar button.text-button:not(.suggested-action):not(.destructive-action), .toolbar button.text-button,
button.flat.text-button {
  min-width: 48px;
  padding-left: 8px;
  padding-right: 8px;
}

infobar.info > revealer > box button.text-button.image-button, infobar.question > revealer > box button.text-button.image-button, filechooser #pathbarbox > stack > box > button.text-button.image-button, window.dialog.message .dialog-action-area > button.text-button.image-button, .app-notification button.text-button.image-button, actionbar > revealer > box button.text-button.image-button:not(.suggested-action):not(.destructive-action), popover.menu button.text-button.image-button.model, .titlebar button.text-button.image-button:not(.suggested-action):not(.destructive-action), .toolbar button.text-button.image-button,
button.flat.text-button.image-button {
  min-width: 24px;
  padding: 6px;
}

infobar.info > revealer > box button.text-button.image-button label:first-child, infobar.question > revealer > box button.text-button.image-button label:first-child, filechooser #pathbarbox > stack > box > button.text-button.image-button label:first-child, window.dialog.message .dialog-action-area > button.text-button.image-button label:first-child, .app-notification button.text-button.image-button label:first-child, actionbar > revealer > box button.text-button.image-button:not(.suggested-action):not(.destructive-action) label:first-child, popover.menu button.text-button.image-button.model label:first-child, .titlebar button.text-button.image-button:not(.suggested-action):not(.destructive-action) label:first-child, .toolbar button.text-button.image-button label:first-child,
button.flat.text-button.image-button label:first-child {
  margin-left: 6px;
}

infobar.info > revealer > box button.text-button.image-button label:last-child, infobar.question > revealer > box button.text-button.image-button label:last-child, filechooser #pathbarbox > stack > box > button.text-button.image-button label:last-child, window.dialog.message .dialog-action-area > button.text-button.image-button label:last-child, .app-notification button.text-button.image-button label:last-child, actionbar > revealer > box button.text-button.image-button:not(.suggested-action):not(.destructive-action) label:last-child, popover.menu button.text-button.image-button.model label:last-child, .titlebar button.text-button.image-button:not(.suggested-action):not(.destructive-action) label:last-child, .toolbar button.text-button.image-button label:last-child,
button.flat.text-button.image-button label:last-child {
  margin-right: 6px;
}

infobar.info > revealer > box .linked:not(.vertical) > button:not(:only-child), infobar.question > revealer > box .linked:not(.vertical) > button:not(:only-child), filechooser #pathbarbox > stack > box.linked:not(.vertical) > button:not(:only-child), window.dialog.message .dialog-action-area.linked:not(.vertical) > button:not(:only-child), .app-notification .linked:not(.vertical) > button:not(:only-child), actionbar > revealer > box .linked:not(.vertical) > button:not(:only-child):not(.suggested-action):not(.destructive-action), popover.menu .linked:not(.vertical) > button.model:not(:only-child), .titlebar .linked:not(.vertical) > button:not(:only-child):not(.suggested-action):not(.destructive-action), .toolbar .linked:not(.vertical) > button:not(:only-child), infobar.info > revealer > box .linked.vertical > button:not(:only-child), infobar.question > revealer > box .linked.vertical > button:not(:only-child), filechooser #pathbarbox > stack > box.linked.vertical > button:not(:only-child), window.dialog.message .dialog-action-area.linked.vertical > button:not(:only-child), .app-notification .linked.vertical > button:not(:only-child), actionbar > revealer > box .linked.vertical > button:not(:only-child):not(.suggested-action):not(.destructive-action), popover.menu .linked.vertical > button.model:not(:only-child), .titlebar .linked.vertical > button:not(:only-child):not(.suggested-action):not(.destructive-action), .toolbar .linked.vertical > button:not(:only-child), .linked:not(.vertical) > button.flat:not(:only-child), .linked.vertical > button.flat:not(:only-child) {
  border-radius: 4px;
}

infobar.info > revealer > box .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), infobar.question > revealer > box .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), filechooser #pathbarbox > stack > box.linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), window.dialog.message .dialog-action-area.linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), .app-notification .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), actionbar > revealer > box .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button):not(.suggested-action):not(.destructive-action), popover.menu .linked:not(.vertical) > button.model.image-button:not(:only-child):not(.text-button), .titlebar .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button):not(.suggested-action):not(.destructive-action), .toolbar .linked:not(.vertical) > button.image-button:not(:only-child):not(.text-button), infobar.info > revealer > box .linked.vertical > button.image-button:not(:only-child):not(.text-button), infobar.question > revealer > box .linked.vertical > button.image-button:not(:only-child):not(.text-button), filechooser #pathbarbox > stack > box.linked.vertical > button.image-button:not(:only-child):not(.text-button), window.dialog.message .dialog-action-area.linked.vertical > button.image-button:not(:only-child):not(.text-button), .app-notification .linked.vertical > button.image-button:not(:only-child):not(.text-button), actionbar > revealer > box .linked.vertical > button.image-button:not(:only-child):not(.text-button):not(.suggested-action):not(.destructive-action), popover.menu .linked.vertical > button.model.image-button:not(:only-child):not(.text-button), .titlebar .linked.vertical > button.image-button:not(:only-child):not(.text-button):not(.suggested-action):not(.destructive-action), .toolbar .linked.vertical > button.image-button:not(:only-child):not(.text-button), .linked:not(.vertical) > button.flat.image-button:not(:only-child):not(.text-button), .linked.vertical > button.flat.image-button:not(:only-child):not(.text-button) {
  border-radius: 9999px;
}

button.osd {
  padding: 12px 16px;
}

button.osd.image-button {
  padding: 12px;
}

button.osd:disabled {
  opacity: 0;
}

button.suggested-action {
  background-color: #1967d2;
  color: #fff;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #1967d2;
}

button.suggested-action:drop(active), button.suggested-action:hover {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #2b73d6;
}

button.suggested-action:focus {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #3579d7;
}

button.suggested-action:active {
  box-shadow: 0 5px 5px -3px rgba(0, 0, 0, 0.2), 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 2px rgba(0, 0, 0, 0.12);
  background-image: radial-gradient(circle, rgba(255, 255, 255, 0.12) 10%, transparent 10%);
}

button.suggested-action:disabled {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.38);
}

button.suggested-action:checked {
  background-color: #3e7fd9;
}

button.suggested-action.flat {
  background-color: transparent;
}

button.suggested-action.flat:drop(active), button.suggested-action.flat:hover {
  background-color: rgba(25, 103, 210, 0.12);
}

button.suggested-action.flat:focus {
  background-color: rgba(25, 103, 210, 0.12);
}

button.suggested-action.flat:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

button.suggested-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

button.suggested-action.flat:checked {
  background-color: rgba(25, 103, 210, 0.16);
}

button.destructive-action {
  background-color: #d93025;
  color: #fff;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #d93025;
}

button.destructive-action:drop(active), button.destructive-action:hover {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #dc4136;
}

button.destructive-action:focus {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #de493f;
}

button.destructive-action:active {
  box-shadow: 0 5px 5px -3px rgba(0, 0, 0, 0.2), 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 2px rgba(0, 0, 0, 0.12);
  background-image: radial-gradient(circle, rgba(255, 255, 255, 0.12) 10%, transparent 10%);
}

button.destructive-action:disabled {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.38);
}

button.destructive-action:checked {
  background-color: #df5148;
}

button.destructive-action.flat {
  background-color: transparent;
}

button.destructive-action.flat:drop(active), button.destructive-action.flat:hover {
  background-color: rgba(217, 48, 37, 0.12);
}

button.destructive-action.flat:focus {
  background-color: rgba(217, 48, 37, 0.12);
}

button.destructive-action.flat:active {
  background-image: radial-gradient(circle, rgba(217, 48, 37, 0.16) 10%, transparent 10%);
}

button.destructive-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

button.destructive-action.flat:checked {
  background-color: rgba(217, 48, 37, 0.16);
}

stackswitcher > button > label {
  margin: 0 -6px;
  padding: 0 6px;
}

stackswitcher > button > image {
  margin: -3px -6px;
  padding: 3px 6px;
}

stackswitcher > button.needs-attention:checked > label,
stackswitcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

button.font > box {
  border-spacing: 6px;
}

button.close, menubutton.circular > button, button.circular {
  border-radius: 9999px;
}

button.sidebar-button, notebook > header > tabs > tab button.flat, spinbutton:not(.vertical) > button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 9999px;
}

stacksidebar.sidebar row.needs-attention > label, stackswitcher > button.needs-attention > label,
stackswitcher > button.needs-attention > image {
  animation: needs-attention 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-repeat: no-repeat;
  background-position: right 3px;
  background-size: 6px 6px;
}

stacksidebar.sidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl),
stackswitcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px;
}

.linked:not(stackswitcher) {
  border-spacing: 6px;
}

.linked:not(.vertical) > button.radio {
  border-radius: 0;
}

.linked:not(.vertical) > button.radio:first-child {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}

.linked:not(.vertical) > button.radio:last-child {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}

.linked:not(.vertical) > button.radio:not(:first-child) {
  margin-left: -6px;
}

.linked.vertical > button.radio {
  border-radius: 0;
}

.linked.vertical > button.radio:first-child {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

.linked.vertical > button.radio:last-child {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

.linked.vertical > button.radio:not(:first-child) {
  margin-top: -6px;
}

/* menu buttons */
modelbutton.flat:drop(active), modelbutton.flat:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

modelbutton.flat:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

modelbutton.flat:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

modelbutton.flat arrow {
  min-width: 16px;
  min-height: 16px;
  color: rgba(0, 0, 0, 0.6);
}

modelbutton.flat arrow:disabled {
  color: rgba(0, 0, 0, 0.26);
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

button.color {
  min-width: 24px;
  min-height: 24px;
  padding: 6px;
}

menubutton > button > box > arrow {
  min-height: 16px;
  min-width: 16px;
}

menubutton > button > box > arrow.none {
  -gtk-icon-source: -gtk-icontheme("open-menu-symbolic");
}

menubutton > button > box > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menubutton > button > box > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menubutton > button > box > arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

menubutton > button > box > arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

/**
 * Links
 */
link {
  color: #1967d2;
}

link:visited {
  color: #9334e6;
}

button.link {
  color: #1967d2;
}

button.link:drop(active), button.link:hover {
  background-color: rgba(25, 103, 210, 0.12);
}

button.link:focus {
  background-color: rgba(25, 103, 210, 0.12);
}

button.link:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

button.link:visited {
  color: #9334e6;
}

button.link:visited:drop(active), button.link:visited:hover {
  background-color: rgba(147, 52, 230, 0.12);
}

button.link:visited:focus {
  background-color: rgba(147, 52, 230, 0.12);
}

button.link:visited:active {
  background-image: radial-gradient(circle, rgba(147, 52, 230, 0.16) 10%, transparent 10%);
}

button.link > label {
  text-decoration-line: underline;
}

/**
 * GtkSpinButton
 */
spinbutton {
  font-feature-settings: "tnum";
}

spinbutton:not(.vertical) > text {
  min-width: 32px;
}

spinbutton:not(.vertical) > button {
  margin: 6px 0;
}

spinbutton:not(.vertical) > button.up:dir(ltr) {
  margin-right: -2px;
}

spinbutton:not(.vertical) > button.up:dir(rtl) {
  margin-left: -2px;
}

spinbutton.vertical > text {
  min-height: 36px;
  min-width: 48px;
  padding: 0;
}

spinbutton.vertical > text > selection {
  background-color: rgba(25, 103, 210, 0.24);
}

spinbutton.vertical button {
  min-height: 36px;
  min-width: 48px;
  padding: 0;
}

spinbutton.vertical button:focus:not(:hover):not(:active) {
  box-shadow: inset 0 0 0 9999px transparent;
}

spinbutton.vertical button.up {
  border-radius: 4px 4px 0 0;
}

spinbutton.vertical button.down {
  border-radius: 0 0 4px 4px;
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) > text {
  min-height: 0;
  padding: 1px 2px;
}

/**
 * ComboBoxes
 */
dropdown arrow,
combobox arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  transition: -gtk-icon-transform 75ms cubic-bezier(0, 0, 0.2, 1);
}

dropdown button:checked arrow,
combobox button:checked arrow {
  color: #1967d2;
  -gtk-icon-transform: rotate(-0.5turn);
}

dropdown > button > box {
  border-spacing: 6px;
}

dropdown > popover.menu > contents {
  padding: 0;
}

dropdown > popover.menu > contents listview {
  padding: 6px 0;
}

dropdown > popover.menu > contents listview > row {
  min-height: 24px;
  padding: 4px 8px;
}

dropdown > popover.menu > contents listview > row:selected {
  background-color: rgba(0, 0, 0, 0.08);
}

.dropdown-searchbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.dropdown-searchbar > entry.search {
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

combobox > box > button > box {
  border-spacing: 6px;
}

combobox cellview {
  margin: -2px;
}

combobox > popover.menu > contents modelbutton {
  padding-left: 8px;
  padding-right: 8px;
}

combobox > .linked:not(.vertical) > entry:not(:only-child):first-child {
  margin-right: -42px;
  padding-right: 36px;
}

combobox > .linked:not(.vertical) > entry:not(:only-child):last-child {
  margin-left: -42px;
  padding-left: 36px;
}

combobox > .linked:not(.vertical) > button:not(:only-child) {
  min-height: 16px;
  min-width: 16px;
  margin: 6px;
  padding: 4px;
  border-radius: 9999px;
}

dropdown > button.toggle,
button.combo:only-child {
  padding-left: 8px;
  padding-right: 8px;
  border-radius: 4px 4px 0 0;
  font-weight: normal;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 0%, transparent 0%) 2/0 0 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
  caret-color: #1967d2;
}

dropdown > button.toggle:focus,
button.combo:only-child:focus {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.1168);
}

dropdown > button.toggle:drop(active), dropdown > button.toggle:hover,
button.combo:only-child:drop(active),
button.combo:only-child:hover {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.0784);
}

dropdown > button.toggle:checked,
button.combo:only-child:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 100%, transparent 100%) 2/0 0 2px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.1168);
}

dropdown > button.toggle:disabled,
button.combo:only-child:disabled {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

dropdown > button.toggle arrow,
button.combo:only-child arrow {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(0, 0, 0, 0.6);
}

dropdown > button.toggle arrow:disabled,
button.combo:only-child arrow:disabled {
  color: rgba(0, 0, 0, 0.26);
}

/**
 * Toolbars
 */
.toolbar {
  padding: 4px;
  border-spacing: 4px;
}

.toolbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.toolbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.toolbar.start {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

.toolbar.end {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

.toolbar.osd.left, .toolbar.osd.right, .toolbar.osd.top, .toolbar.osd.bottom {
  border-radius: 0;
}

.toolbar.osd.bottom {
  box-shadow: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, transparent, rgba(0, 0, 0, 0.1) 30%, rgba(0, 0, 0, 0.2) 50%, rgba(0, 0, 0, 0.4));
}

.toolbar.horizontal > separator {
  margin: 4px 0;
}

.toolbar.vertical > separator {
  margin: 0 4px;
}

.app-notification, .toolbar.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  padding: 6px;
  border-spacing: 6px;
  border-radius: 4px;
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #fff;
}

.app-notification:backdrop, .toolbar.osd:backdrop {
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
}

.inline-toolbar {
  padding: 6px;
  border-style: solid;
  border-width: 0 1px 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #fff;
}

searchbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

/**
 * Title buttons
 */
windowcontrols {
  border-spacing: 6px;
}

windowcontrols:not(:only-child):not(.empty) {
  border-image: linear-gradient(to bottom, transparent 12px, rgba(0, 0, 0, 0.12) 12px, rgba(0, 0, 0, 0.12) calc(100% - 12px), transparent calc(100% - 12px)) 1;
}

windowcontrols.start:not(:only-child):not(.empty):dir(ltr), windowcontrols.end:not(:only-child):not(.empty):dir(rtl) {
  padding-right: 6px;
  border-right: 1px solid;
}

windowcontrols.start:not(:only-child):not(.empty):dir(rtl), windowcontrols.end:not(:only-child):not(.empty):dir(ltr) {
  padding-left: 6px;
  border-left: 1px solid;
}

/**
 * Header bars
 */
.titlebar {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), color 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 4px 4px 0 0;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #f0f0f0;
  color: rgba(0, 0, 0, 0.87);
}

.titlebar:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar:backdrop {
  background-color: #ebebeb;
  color: rgba(0, 0, 0, 0.6);
}

.titlebar:backdrop:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.titlebar box.start,
.titlebar box.end {
  border-spacing: 6px;
}

.titlebar .title {
  padding-left: 12px;
  padding-right: 12px;
  font-weight: bold;
}

.titlebar .subtitle {
  padding-left: 12px;
  padding-right: 12px;
  font-size: smaller;
}

.titlebar .subtitle,
.titlebar .dim-label {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(0, 0, 0, 0.6);
}

.titlebar .subtitle:backdrop,
.titlebar .dim-label:backdrop {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar headerbar + separator {
  background-color: rgba(0, 0, 0, 0.12);
}

.titlebar entry {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
}

.titlebar entry:disabled {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

.titlebar entry image {
  color: rgba(0, 0, 0, 0.6);
}

.titlebar entry image:hover, .titlebar entry image:active {
  color: rgba(0, 0, 0, 0.87);
}

.titlebar entry image:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar .linked:not(.vertical) > entry:not(:only-child) {
  border-radius: 4px 4px 0 0;
}

.titlebar button:not(.suggested-action):not(.destructive-action) {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 0%, transparent 0%) 0 0 0/0 0 0px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
}

.titlebar button:not(.suggested-action):not(.destructive-action):drop(active), .titlebar button:not(.suggested-action):not(.destructive-action):hover {
  background-color: rgba(0, 0, 0, 0.08);
}

.titlebar button:not(.suggested-action):not(.destructive-action):focus {
  background-color: rgba(0, 0, 0, 0.08);
}

.titlebar button:not(.suggested-action):not(.destructive-action):active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

.titlebar button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(0, 0, 0, 0.26);
}

.titlebar button:not(.suggested-action):not(.destructive-action):checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 100%, transparent 100%) 0 0 2/0 0 2px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

.titlebar button:not(.suggested-action):not(.destructive-action):checked:drop(active), .titlebar button:not(.suggested-action):not(.destructive-action):checked:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

.titlebar button:not(.suggested-action):not(.destructive-action):checked:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

.titlebar button:not(.suggested-action):not(.destructive-action):checked:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

.titlebar button:not(.suggested-action):not(.destructive-action):checked:disabled {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
}

.titlebar button:not(.suggested-action):not(.destructive-action):backdrop {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar button:not(.suggested-action):not(.destructive-action):backdrop:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.titlebar button:not(.suggested-action):not(.destructive-action):backdrop:checked {
  color: rgba(0, 0, 0, 0.6);
}

.titlebar button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.titlebar button.suggested-action:disabled,
.titlebar button.destructive-action:disabled {
  background-color: rgba(0, 0, 0, 0.08);
  color: rgba(0, 0, 0, 0.38);
}

.titlebar stackswitcher button.text-button:not(.suggested-action):not(.destructive-action) {
  min-width: 104px;
}

.titlebar .path-bar button.text-button:not(.suggested-action):not(.destructive-action) {
  min-width: 0;
  padding-left: 6px;
  padding-right: 6px;
}

.titlebar.selection-mode {
  transition: background-color 0.1ms 225ms, color 75ms cubic-bezier(0, 0, 0.2, 1);
  animation: ripple-on-headerbar 225ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.2);
  background-color: #1967d2;
  color: #fff;
}

.titlebar.selection-mode:backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode .subtitle:link {
  color: #fff;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action) {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0/0 0 0px;
  color: #fff;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(255, 255, 255, 0.5);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 100%) 0 0 2/0 0 2px;
  color: #fff;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar.selection-mode .selection-menu {
  padding-left: 16px;
  padding-right: 16px;
}

.titlebar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.titlebar .selection-mode {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.2);
  background-color: #1967d2;
}

.tiled .titlebar, .tiled-top .titlebar, .tiled-right .titlebar, .tiled-bottom .titlebar, .tiled-left .titlebar, .maximized .titlebar, .fullscreen .titlebar {
  border-radius: 0;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

.titlebar.default-decoration {
  min-height: 24px;
  padding: 6px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

.tiled .titlebar.default-decoration, .maximized .titlebar.default-decoration, .fullscreen .titlebar.default-decoration {
  box-shadow: none;
}

.titlebar.default-decoration button.titlebutton {
  min-height: 24px;
  min-width: 24px;
  margin: 0;
  padding: 0;
}

.background:not(.csd) .titlebar.default-decoration button.titlebutton:active {
  background-size: 1000% 1000%;
}

.solid-csd .titlebar:dir(rtl), .solid-csd .titlebar:dir(ltr) {
  border-radius: 0;
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

headerbar > windowhandle > box {
  min-height: 48px;
  padding: 0 6px;
  border-spacing: 6px;
}

headerbar > windowhandle > box entry,
headerbar > windowhandle > box spinbutton,
headerbar > windowhandle > box button {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar > windowhandle > box separator.titlebutton {
  margin-top: 12px;
  margin-bottom: 12px;
  background-color: rgba(0, 0, 0, 0.12);
}

headerbar > windowhandle > box switch {
  margin-top: 12px;
  margin-bottom: 12px;
}

headerbar > windowhandle > box spinbutton button {
  margin-top: 0;
  margin-bottom: 0;
}

headerbar > windowhandle > box .entry-tag {
  margin-top: 5px;
  margin-bottom: 5px;
}

/**
 * Pathbars
 */

pathbar.linked:not(.vertical) > button {
  padding-left: 6px;
  padding-right: 6px;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 0%, transparent 0%) 0 0 0/0 0 0px;
  border-radius: 4px;
}


pathbar.linked:not(.vertical) > button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1967d2 100%, transparent 100%) 0 0 2/0 0 2px;
  color: rgba(0, 0, 0, 0.87);
}


pathbar.linked:not(.vertical) > button:checked,
pathbar.linked:not(.vertical) > button:checked:disabled {
  background-color: transparent;
}


pathbar.linked:not(.vertical) > button label:not(:only-child):first-child {
  margin-left: 0;
}


pathbar.linked:not(.vertical) > button label:not(:only-child):last-child {
  margin-right: 0;
}


pathbar.linked:not(.vertical) > button.text-button {
  min-width: 0;
}


pathbar.linked:not(.vertical) > button.slider-button {
  padding-left: 4px;
  padding-right: 4px;
}

/**
 * Tree Views
 */
columnview.view,
treeview.view {
  border-left-color: rgba(0, 0, 0, 0.26);
  border-top-color: rgba(0, 0, 0, 0.12);
}

columnview.view.separator,
treeview.view.separator {
  min-height: 5px;
  color: rgba(0, 0, 0, 0.12);
}

columnview.view:drop(active),
treeview.view:drop(active) {
  box-shadow: none;
}

columnview.view > dndtarget:drop(active),
treeview.view > dndtarget:drop(active) {
  border-style: solid none;
  border-width: 9999px;
  border-color: rgba(0, 0, 0, 0.08);
}

columnview.view > dndtarget.after:drop(active),
treeview.view > dndtarget.after:drop(active) {
  border-top-style: none;
}

columnview.view > dndtarget.before:drop(active),
treeview.view > dndtarget.before:drop(active) {
  border-bottom-style: none;
}

columnview.view.expander,
treeview.view.expander {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -gtk-icon-transform: rotate(-90deg);
  color: rgba(0, 0, 0, 0.6);
}

columnview.view.expander:dir(rtl),
treeview.view.expander:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

columnview.view.expander:checked,
treeview.view.expander:checked {
  -gtk-icon-transform: unset;
}

columnview.view.expander:hover, columnview.view.expander:active,
treeview.view.expander:hover,
treeview.view.expander:active {
  color: rgba(0, 0, 0, 0.87);
}

columnview.view.expander:disabled,
treeview.view.expander:disabled {
  color: rgba(0, 0, 0, 0.26);
}

columnview.view.progressbar,
treeview.view.progressbar {
  border-bottom: 4px solid #1967d2;
  background-color: transparent;
}

columnview.view.progressbar:selected:hover,
treeview.view.progressbar:selected:hover {
  background-color: transparent;
}

columnview.view.trough,
treeview.view.trough {
  border-bottom: 4px solid rgba(0, 0, 0, 0.12);
  background-color: transparent;
}

columnview.view.trough:selected:hover,
treeview.view.trough:selected:hover {
  background-color: transparent;
}

columnview.view > header > button,
treeview.view > header > button {
  padding: 2px 6px;
  border-style: none solid solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  background-clip: padding-box;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
  background-color: transparent;
}

columnview.view > header > button:drop(active), columnview.view > header > button:hover,
treeview.view > header > button:drop(active),
treeview.view > header > button:hover {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.04);
}

columnview.view > header > button:focus,
treeview.view > header > button:focus {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
}

columnview.view > header > button:active,
treeview.view > header > button:active {
  box-shadow: none;
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

columnview.view > header > button:drop(active):not(:active), columnview.view > header > button:hover:not(:active),
treeview.view > header > button:drop(active):not(:active),
treeview.view > header > button:hover:not(:active) {
  transition-property: all, border-image, background-size, background-image, background-color;
  transition-duration: 75ms, 225ms, 300ms, 1200ms, 0ms;
}

columnview.view > header > button:disabled,
treeview.view > header > button:disabled {
  color: rgba(0, 0, 0, 0.26);
}

columnview.view > header > button:last-child,
treeview.view > header > button:last-child {
  border-right-style: none;
}

columnview.view > header > button > box > sort-indicator,
treeview.view > header > button > box > sort-indicator {
  min-height: 16px;
  min-width: 16px;
}

columnview.view > header > button > box > sort-indicator.ascending,
treeview.view > header > button > box > sort-indicator.ascending {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

columnview.view > header > button > box > sort-indicator.descending,
treeview.view > header > button > box > sort-indicator.descending {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

columnview.view button.dnd,
columnview.view header.button.dnd,
treeview.view button.dnd,
treeview.view header.button.dnd {
  padding: 2px 6px;
  border-style: none solid solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
  background-clip: border-box;
  color: #1967d2;
}

columnview.view acceleditor > label,
treeview.view acceleditor > label {
  background-color: #1967d2;
}

/**
 * Menus
 */
menubar {
  background-color: #f0f0f0;
  color: rgba(0, 0, 0, 0.87);
}

menubar:backdrop {
  background-color: #ebebeb;
  color: rgba(0, 0, 0, 0.6);
}

.csd menubar {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
}

menubar > item {
  min-height: 20px;
  padding: 4px 8px;
  color: rgba(0, 0, 0, 0.6);
}

menubar > item:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

menubar > item:focus:not(:hover) {
  background-color: rgba(0, 0, 0, 0.08);
}

menubar > item:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

menubar > item:selected:not(:focus) {
  transition: none;
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

menubar > item:disabled {
  color: rgba(0, 0, 0, 0.26);
}

popover.menu > contents {
  padding: 6px 0;
}

popover.menu separator {
  margin: 6px 0;
}

popover.menu label.title {
  min-height: 24px;
  padding: 4px 32px;
  font-weight: bold;
}

popover.menu modelbutton {
  min-height: 22px;
  min-width: 40px;
  padding: 4px 32px;
}

popover.menu modelbutton:disabled {
  color: rgba(0, 0, 0, 0.38);
}

popover.menu modelbutton accelerator {
  color: rgba(0, 0, 0, 0.6);
}

popover.menu modelbutton accelerator:dir(ltr) {
  margin-left: 24px;
  margin-right: -16px;
}

popover.menu modelbutton accelerator:dir(rtl) {
  margin-left: -16px;
  margin-right: 24px;
}

popover.menu modelbutton:disabled accelerator {
  color: rgba(0, 0, 0, 0.26);
}

popover.menu check, popover.menu check:focus, popover.menu check:hover, popover.menu check:active, popover.menu check:disabled,
popover.menu radio,
popover.menu radio:focus,
popover.menu radio:hover,
popover.menu radio:active,
popover.menu radio:disabled {
  background-color: transparent;
  background-image: none;
}

popover.menu arrow,
popover.menu check,
popover.menu radio {
  min-width: 16px;
  min-height: 16px;
  margin: 0;
  padding: 0;
}

popover.menu arrow.left,
popover.menu check.left,
popover.menu radio.left {
  margin-left: -24px;
  margin-right: 8px;
}

popover.menu arrow.right,
popover.menu check.right,
popover.menu radio.right {
  margin-left: 8px;
  margin-right: -24px;
}

popover.menu box.inline-buttons {
  padding: 0 8px;
}

popover.menu box.circular-buttons {
  padding: 4px 32px;
}

popover.menu box.circular-buttons button.circular.image-button.model {
  padding: 12px;
}

/**
 * Popovers
 */
popover {
  font: initial;
}

popover.background {
  background-color: transparent;
}

popover > arrow,
popover > contents {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

popover > arrow:backdrop,
popover > contents:backdrop {
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

popover > arrow {
  border-width: 1px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.2) rgba(0, 0, 0, 0.3);
  background-clip: padding-box;
}

popover > contents {
  padding: 8px;
  border-radius: 4px;
}

popover > contents > list,
popover > contents .view,
popover > contents > .toolbar {
  border-style: none;
  box-shadow: none;
  background-color: transparent;
}

popover frame,
popover .frame {
  border: 1px solid rgba(0, 0, 0, 0.12);
  box-shadow: none;
  background-color: transparent;
}

/**
 * Notebooks
 */
notebook:focus:focus-visible > header > tabs > tab:checked {
  background-color: rgba(25, 103, 210, 0.12);
}

notebook > header.top {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

notebook > header.top > tabs > tab {
  box-shadow: inset 0 -2px transparent;
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -2px #1967d2;
}

notebook > header.bottom {
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.12);
}

notebook > header.bottom > tabs > tab {
  box-shadow: inset 0 2px transparent;
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 2px #1967d2;
}

notebook > header.left {
  box-shadow: inset -1px 0 rgba(0, 0, 0, 0.12);
}

notebook > header.left > tabs > tab {
  box-shadow: inset -2px 0 transparent;
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -2px 0 #1967d2;
}

notebook > header.right {
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.12);
}

notebook > header.right > tabs > tab {
  box-shadow: inset 2px 0 transparent;
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 2px 0 #1967d2;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header > tabs > arrow {
  min-height: 16px;
  min-width: 16px;
  padding: 4px;
  border-radius: 0;
  color: rgba(0, 0, 0, 0.6);
}

notebook > header > tabs > arrow:drop(active), notebook > header > tabs > arrow:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

notebook > header > tabs > arrow:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

notebook > header > tabs > arrow:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

notebook > header > tabs > arrow:disabled {
  color: rgba(0, 0, 0, 0.26);
}

notebook > header > tabs > tab {
  min-height: 24px;
  min-width: 24px;
  padding: 6px 12px;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

notebook > header > tabs > tab:drop(active), notebook > header > tabs > tab:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

notebook > header > tabs > tab:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

notebook > header > tabs > tab:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

notebook > header > tabs > tab:disabled {
  color: rgba(0, 0, 0, 0.26);
}

notebook > header > tabs > tab:checked {
  color: #1967d2;
}

notebook > header > tabs > tab:checked:drop(active), notebook > header > tabs > tab:checked:hover {
  background-color: rgba(25, 103, 210, 0.08);
}

notebook > header > tabs > tab:checked:focus {
  background-color: rgba(25, 103, 210, 0.12);
}

notebook > header > tabs > tab:checked:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

notebook > header > tabs > tab:checked:disabled {
  color: rgba(0, 0, 0, 0.26);
}

notebook > header > tabs > tab > box {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: -6px -12px;
  padding: 6px 12px;
}

notebook > header > tabs > tab > box:drop(active) {
  background-color: rgba(0, 0, 0, 0.08);
}

notebook > header > tabs > tab button.flat:last-child {
  margin-left: 6px;
  margin-right: -6px;
}

notebook > header > tabs > tab button.flat:first-child {
  margin-left: -6px;
  margin-right: 6px;
}

/**
 * Scrollbars
 */
scrollbar {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  background-clip: padding-box;
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar > range > trough > slider {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 10px;
  min-height: 10px;
  border: 3px solid transparent;
  border-radius: 9999px;
  background-clip: padding-box;
  background-color: rgba(0, 0, 0, 0.38);
}

scrollbar > range > trough > slider:hover {
  background-color: rgba(0, 0, 0, 0.48);
}

scrollbar > range > trough > slider:active {
  background-color: rgba(0, 0, 0, 0.6);
}

scrollbar > range > trough > slider:disabled {
  background-color: rgba(0, 0, 0, 0.26);
}

scrollbar.horizontal > range > trough > slider {
  min-width: 24px;
}

scrollbar.vertical > range > trough > slider {
  min-height: 24px;
}

scrollbar > range.fine-tune > trough > slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar > range.fine-tune.horizontal > trough > slider {
  margin: 3px 0;
}

scrollbar > range.fine-tune.vertical > trough > slider {
  margin: 0 3px;
}

scrollbar.overlay-indicator > range:not(.fine-tune) > trough > slider {
  transition-property: background-color, min-height, min-width;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) > range > trough > slider {
  min-width: 4px;
  min-height: 4px;
  margin: 2px;
  border: 1px solid rgba(255, 255, 255, 0.3);
}

scrollbar.overlay-indicator.horizontal:not(.dragging):not(.hovering) > range > trough > slider {
  min-width: 24px;
}

scrollbar.overlay-indicator.vertical:not(.dragging):not(.hovering) > range > trough > slider {
  min-height: 24px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  background-color: #fff;
}

/**
 * Switch
 */
switch {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: 6px 0;
  padding: 0 2px;
  border: 5px solid transparent;
  border-radius: 9999px;
  background-color: rgba(0, 0, 0, 0.26);
  background-clip: padding-box;
  font-size: 0;
}

switch:checked {
  background-color: rgba(25, 103, 210, 0.5);
}

switch:disabled {
  opacity: .5;
}

switch > image {
  margin: -8px;
  -gtk-icon-transform: scale(0);
}

switch > slider {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 20px;
  min-height: 20px;
  margin: -3px -2px;
  border-radius: 9999px;
  box-shadow: 0 0 0 10px transparent, 0 0 0 -10px rgba(0, 0, 0, 0.12), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
}

switch:hover > slider {
  box-shadow: 0 0 0 10px rgba(0, 0, 0, 0.08), 0 0 0 -10px rgba(0, 0, 0, 0.12), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

switch:focus > slider {
  box-shadow: 0 0 0 10px rgba(0, 0, 0, 0.08), 0 0 0 -10px rgba(0, 0, 0, 0.12), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

switch:active > slider {
  box-shadow: 0 0 0 10px rgba(0, 0, 0, 0.08), 0 0 0 10px rgba(0, 0, 0, 0.12), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

switch:checked > slider {
  background-color: #1967d2;
}

switch:checked:hover > slider {
  box-shadow: 0 0 0 10px rgba(25, 103, 210, 0.12), 0 0 0 -10px rgba(25, 103, 210, 0.16), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

switch:checked:focus > slider {
  box-shadow: 0 0 0 10px rgba(25, 103, 210, 0.12), 0 0 0 -10px rgba(25, 103, 210, 0.16), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

switch:checked:active > slider {
  box-shadow: 0 0 0 10px rgba(25, 103, 210, 0.12), 0 0 0 10px rgba(25, 103, 210, 0.16), 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

/**
 * Check and Radio items
 */
.view.content-view.check:not(list),
.content-view:not(list) .tile check {
  min-height: 40px;
  min-width: 40px;
  margin: 0;
  padding: 0;
  background-color: transparent;
  background-image: none;
  -gtk-icon-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 2px 2px rgba(0, 0, 0, 0.14), 0 1px 5px rgba(0, 0, 0, 0.12);
}

.view.content-view.check:not(list):hover, .view.content-view.check:not(list):active,
.content-view:not(list) .tile check:hover,
.content-view:not(list) .tile check:active {
  -gtk-icon-shadow: 0 2px 3px rgba(0, 0, 0, 0.2), 0 4px 5px rgba(0, 0, 0, 0.14), 0 1px 10px rgba(0, 0, 0, 0.12);
}

.view.content-view.check:not(list),
.content-view:not(list) .tile check {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-unchecked.png"), url("assets/selectionmode-checkbox-unchecked@2.png"));
}

.view.content-view.check:not(list):checked,
.content-view:not(list) .tile check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-checked.png"), url("assets/selectionmode-checkbox-checked@2.png"));
}

checkbutton,
radiobutton {
  border-spacing: 4px;
}

checkbutton.text-button,
radiobutton.text-button {
  padding: 4px;
}

check,
radio {
  min-height: 24px;
  min-width: 24px;
  margin: -8px;
  padding: 8px;
  border-radius: 9999px;
  color: rgba(0, 0, 0, 0.6);
}

check:drop(active), check:hover,
radio:drop(active),
radio:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

check:focus,
radio:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

check:active,
radio:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  color: #1967d2;
}

check:checked:drop(active), check:checked:hover, check:indeterminate:drop(active), check:indeterminate:hover,
radio:checked:drop(active),
radio:checked:hover,
radio:indeterminate:drop(active),
radio:indeterminate:hover {
  background-color: rgba(25, 103, 210, 0.12);
}

check:checked:focus, check:indeterminate:focus,
radio:checked:focus,
radio:indeterminate:focus {
  background-color: rgba(25, 103, 210, 0.12);
}

check:checked:active, check:indeterminate:active,
radio:checked:active,
radio:indeterminate:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

check:disabled,
radio:disabled {
  color: rgba(0, 0, 0, 0.26);
}


check {
  -gtk-icon-source: -gtk-recolor(url("icons/checkbox-unchecked-symbolic.svg"));
}


check:checked {
  -gtk-icon-source: -gtk-recolor(url("icons/checkbox-checked-symbolic.svg"));
}


check:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("icons/checkbox-mixed-symbolic.svg"));
}


radio {
  -gtk-icon-source: -gtk-recolor(url("icons/radio-unchecked-symbolic.svg"));
  border-image-slice: 20;
  border-image-width: 20px;
  border-image-source: radial-gradient(circle, #1967d2 0%, transparent 0%);
}


radio:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("icons/radio-mixed-symbolic.svg"));
}


radio:checked:not(:indeterminate) {
  border-image-source: radial-gradient(circle, #1967d2 4.5px, transparent 5px);
}


radio:checked:not(:indeterminate):disabled {
  border-image-source: radial-gradient(circle, rgba(0, 0, 0, 0.26) 4.5px, transparent 5px);
}


popover.menu modelbutton check {
  min-height: 16px;
  min-width: 16px;
  border-radius: 4px;
  -gtk-icon-source: -gtk-recolor(url("icons/small-checkbox-unchecked-symbolic.svg"));
}


popover.menu modelbutton check:checked {
  -gtk-icon-source: -gtk-recolor(url("icons/small-checkbox-checked-symbolic.svg"));
}


popover.menu modelbutton check:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("icons/small-checkbox-mixed-symbolic.svg"));
}


popover.menu modelbutton radio {
  min-height: 16px;
  min-width: 16px;
  border-image: none;
  -gtk-icon-source: -gtk-recolor(url("icons/small-radio-unchecked-symbolic.svg"));
}


popover.menu modelbutton radio:checked {
  -gtk-icon-source: -gtk-recolor(url("icons/small-radio-checked-symbolic.svg"));
}


popover.menu modelbutton radio:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("icons/small-radio-mixed-symbolic.svg"));
}

treeview.view check,
treeview.view radio {
  padding: 0;
  color: rgba(0, 0, 0, 0.6);
}

treeview.view check:checked, treeview.view check:indeterminate,
treeview.view radio:checked,
treeview.view radio:indeterminate {
  color: #1967d2;
}

treeview.view check:disabled,
treeview.view radio:disabled {
  color: rgba(0, 0, 0, 0.26);
}

treeview.view check, treeview.view check:hover, treeview.view check:selected, treeview.view check:selected:hover,
treeview.view radio,
treeview.view radio:hover,
treeview.view radio:selected,
treeview.view radio:selected:hover {
  background-color: transparent;
}

treeview.view radio:checked {
  -gtk-icon-source: -gtk-recolor(url("icons/radio-checked-symbolic.svg"));
  border-image: none;
}

/**
 * GtkScale
 */
scale {
  min-height: 2px;
  min-width: 2px;
}

scale.horizontal {
  padding: 17px 12px;
}

scale.vertical {
  padding: 12px 17px;
}

scale.fine-tune.horizontal {
  min-height: 4px;
  padding-top: 16px;
  padding-bottom: 16px;
}

scale.fine-tune.vertical {
  min-width: 4px;
  padding-left: 16px;
  padding-right: 16px;
}

scale.fine-tune > trough > slider {
  margin: -14px;
}

scale > trough {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: rgba(0, 0, 0, 0.26);
}

scale > trough:disabled {
  background-color: rgba(0, 0, 0, 0.12);
}

scale > trough > highlight {
  transition: background-image 75ms cubic-bezier(0, 0, 0.2, 1);
  background-image: image(#1967d2);
}

scale > trough > highlight:disabled {
  background-color: #f9f9f9;
  background-image: image(rgba(0, 0, 0, 0.26));
}

scale > trough > fill {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: rgba(0, 0, 0, 0.26);
}

scale > trough > fill:disabled {
  background-color: transparent;
}

scale > trough > slider {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 32px;
  min-height: 32px;
  margin: -15px;
  border-radius: 50%;
  background-repeat: no-repeat;
  background-position: center;
  background-size: auto, 1000% 1000%;
  color: #1967d2;
}

scale > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-slider.png"), url("assets/scale-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-slider-disabled.png"), url("assets/scale-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale > trough > slider:hover {
  background-color: rgba(25, 103, 210, 0.12);
}

scale > trough > slider:focus {
  background-color: rgba(25, 103, 210, 0.12);
}

scale > trough > slider:active {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple-on-slider 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-image: -gtk-scaled(url("assets/scale-slider.png"), url("assets/scale-slider@2.png")), radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
  background-size: auto, 0% 0%;
}

scale > marks,
scale > value {
  color: rgba(0, 0, 0, 0.6);
}

scale > value {
  font-feature-settings: "tnum";
}

scale indicator {
  background-color: rgba(0, 0, 0, 0.26);
}

scale.horizontal > marks.top {
  margin-bottom: 7px;
  margin-top: -15px;
}

scale.horizontal.fine-tune > marks.top {
  margin-bottom: 6px;
  margin-top: -14px;
}

scale.horizontal > marks.bottom {
  margin-top: 7px;
  margin-bottom: -15px;
}

scale.horizontal.fine-tune > marks.bottom {
  margin-top: 6px;
  margin-bottom: -14px;
}

scale.vertical > marks.top {
  margin-right: 7px;
  margin-left: -15px;
}

scale.vertical.fine-tune > marks.top {
  margin-right: 6px;
  margin-left: -14px;
}

scale.vertical > marks.bottom {
  margin-left: 7px;
  margin-right: -15px;
}

scale.vertical.fine-tune > marks.bottom {
  margin-left: 6px;
  margin-right: -14px;
}

scale.horizontal indicator {
  min-height: 8px;
  min-width: 1px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 8px;
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider.png"), url("assets/scale-horz-marks-before-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider-disabled.png"), url("assets/scale-horz-marks-before-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.horizontal.marks-before:not(.marks-after) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider.png"), url("assets/scale-horz-marks-before-slider@2.png")), radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider.png"), url("assets/scale-horz-marks-after-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider-disabled.png"), url("assets/scale-horz-marks-after-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.horizontal.marks-after:not(.marks-before) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider.png"), url("assets/scale-horz-marks-after-slider@2.png")), radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider.png"), url("assets/scale-vert-marks-before-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider-disabled.png"), url("assets/scale-vert-marks-before-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.vertical.marks-before:not(.marks-after) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider.png"), url("assets/scale-vert-marks-before-slider@2.png")), radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider.png"), url("assets/scale-vert-marks-after-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider-disabled.png"), url("assets/scale-vert-marks-after-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 10%);
}

scale.vertical.marks-after:not(.marks-before) > trough > slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider.png"), url("assets/scale-vert-marks-after-slider@2.png")), radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

scale.color {
  min-height: 0;
  min-width: 0;
}

scale.color.horizontal:dir(ltr), scale.color.horizontal:dir(rtl) {
  padding: 0 0 12px 0;
}

scale.color.horizontal:dir(ltr) slider, scale.color.horizontal:dir(rtl) slider {
  margin-bottom: -24px;
  margin-top: 8px;
}

scale.color.vertical:dir(ltr) {
  padding: 0 0 0 12px;
}

scale.color.vertical:dir(ltr) slider {
  margin-left: -24px;
  margin-right: 8px;
}

scale.color.vertical:dir(rtl) {
  padding: 0 12px 0 0;
}

scale.color.vertical:dir(rtl) slider {
  margin-right: -24px;
  margin-left: 8px;
}

/**
 * Progress bars
 */
progressbar {
  color: rgba(0, 0, 0, 0.6);
  font-size: smaller;
  font-feature-settings: "tnum";
}

progressbar > trough {
  background-color: rgba(0, 0, 0, 0.12);
}

progressbar > trough > progress {
  background-color: #1967d2;
}

progressbar.horizontal > trough {
  min-width: 150px;
}

progressbar.horizontal > trough,
progressbar.horizontal > trough > progress {
  min-height: 4px;
}

progressbar.vertical > trough {
  min-height: 80px;
}

progressbar.vertical > trough,
progressbar.vertical > trough > progress {
  min-width: 4px;
}

progressbar > trough.empty > progress {
  all: unset;
}

/**
 * Level Bar
 */
levelbar.horizontal > trough > block {
  min-height: 4px;
}

levelbar.horizontal.discrete > trough > block {
  min-width: 36px;
}

levelbar.horizontal.discrete > trough > block:not(:last-child) {
  margin-right: 2px;
}

levelbar.vertical > trough > block {
  min-width: 4px;
}

levelbar.vertical.discrete > trough > block {
  min-height: 36px;
}

levelbar.vertical.discrete > trough > block:not(:last-child) {
  margin-bottom: 2px;
}

levelbar > trough > block.low {
  background-color: #f9ab00;
}

levelbar > trough > block.high, levelbar > trough > block:not(.empty) {
  background-color: #1967d2;
}

levelbar > trough > block.full {
  background-color: #1e8e3e;
}

levelbar > trough > block.empty {
  background-color: rgba(0, 0, 0, 0.12);
}

/**
 * Print dialog
 */
window.dialog.print paper {
  border-radius: 4px;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

window.dialog.print .dialog-action-box {
  margin: 12px;
}

/**
 * Frames
 */
frame,
.frame {
  border-radius: 4px;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

frame > label {
  margin: 4px;
}

statusbar {
  padding: 6px 10px;
}

actionbar > revealer > box {
  padding: 6px;
  border-spacing: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

actionbar > revealer > box .linked:not(.vertical) > entry:not(:only-child) {
  border-radius: 4px 4px 0 0;
}

overshoot.top {
  background-image: radial-gradient(farthest-side at top, rgba(25, 103, 210, 0.24) 99%, rgba(25, 103, 210, 0) 100%);
  background-size: 200% 75%;
  background-repeat: no-repeat;
  background-position: top;
}

overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, rgba(25, 103, 210, 0.24) 99%, rgba(25, 103, 210, 0) 100%);
  background-size: 200% 75%;
  background-repeat: no-repeat;
  background-position: bottom;
}

overshoot.left {
  background-image: radial-gradient(farthest-side at left, rgba(25, 103, 210, 0.24) 99%, rgba(25, 103, 210, 0) 100%);
  background-size: 75% 200%;
  background-repeat: no-repeat;
  background-position: left;
}

overshoot.right {
  background-image: radial-gradient(farthest-side at right, rgba(25, 103, 210, 0.24) 99%, rgba(25, 103, 210, 0) 100%);
  background-size: 75% 200%;
  background-repeat: no-repeat;
  background-position: right;
}

junction {
  border-style: solid none none solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
}

junction:dir(rtl) {
  border-style: solid solid none none;
}

separator {
  min-width: 1px;
  min-height: 1px;
  background-color: rgba(0, 0, 0, 0.12);
}

button.font > box > box > separator {
  min-width: 0;
  min-height: 0;
  background-color: transparent;
}

/**
 * Lists
 */
listview > row,
list > row {
  padding: 2px;
}

listview > row.expander,
list > row.expander {
  padding: 0;
}

listview > row.expander .row-header,
list > row.expander .row-header {
  padding: 2px;
}

listview.separators:not(.horizontal) > row:not(:first-child),
list.separators:not(.horizontal) > row:not(:first-child) {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

listview.separators.horizontal > row:not(:first-child),
list.separators.horizontal > row:not(:first-child) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

row {
  background-clip: padding-box;
}

row.activatable:drop(active), row.activatable:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

row.activatable:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

row.activatable:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

row.activatable:drop(active):not(:active), row.activatable:hover:not(:active) {
  transition-property: all, border-image, background-size, background-image, background-color;
  transition-duration: 75ms, 225ms, 300ms, 1200ms, 0ms;
}

row.activatable.has-open-popup {
  background-color: rgba(0, 0, 0, 0.12);
}

row:selected {
  background-color: rgba(25, 103, 210, 0.24);
  background-color: rgba(25, 103, 210, 0.24);
}

row:selected:drop(active), row:selected:hover {
  background-color: rgba(25, 103, 210, 0.3008);
}

row:selected:focus {
  background-color: rgba(25, 103, 210, 0.3312);
}

row:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

row.has-open-popup:selected {
  background-color: rgba(25, 103, 210, 0.3616);
}

listview > row:drop(active), listview > row:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

listview > row:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

listview > row:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

listview > row:drop(active):not(:active), listview > row:hover:not(:active) {
  transition-property: all, border-image, background-size, background-image, background-color;
  transition-duration: 75ms, 225ms, 300ms, 1200ms, 0ms;
}

listview:selected {
  background-color: rgba(25, 103, 210, 0.24);
  background-color: rgba(25, 103, 210, 0.24);
}

listview:selected:drop(active), listview:selected:hover {
  background-color: rgba(25, 103, 210, 0.3008);
}

listview:selected:focus {
  background-color: rgba(25, 103, 210, 0.3312);
}

listview:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

columnview > listview > row {
  padding: 0;
}

columnview > listview > row > cell {
  min-height: 24px;
  padding: 4px 6px;
}

columnview > listview > row > cell:not(:last-child) {
  border-right: 1px solid transparent;
}

columnview.column-separators > listview > row > cell {
  border-right-color: rgba(0, 0, 0, 0.12);
}

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px;
}

.rich-list > row {
  padding: 12px;
  min-height: 36px;
}

.rich-list > row > box {
  border-spacing: 12px;
}

/**
 * App Notifications
 */
.app-notification {
  margin: 8px;
  border-style: none;
}

.app-notification button.text-button:not(:disabled) {
  color: #1967d2;
}

.app-notification button.text-button:not(:disabled):drop(active), .app-notification button.text-button:not(:disabled):hover {
  background-color: rgba(25, 103, 210, 0.12);
}

.app-notification button.text-button:not(:disabled):focus {
  background-color: rgba(25, 103, 210, 0.12);
}

.app-notification button.text-button:not(:disabled):active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

/**
 * Expanders
 */
expander {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
  border-radius: 9999px;
  color: rgba(0, 0, 0, 0.6);
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

expander:drop(active), expander:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

expander:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

expander:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

expander:disabled {
  color: rgba(0, 0, 0, 0.26);
}

expander:checked:dir(ltr) {
  -gtk-icon-transform: rotate(-180deg);
}

expander:checked:dir(rtl) {
  -gtk-icon-transform: rotate(180deg);
}

indent {
  min-width: 16px;
  min-height: 16px;
  padding: 4px;
}

expander-widget:focus > box > title > expander {
  box-shadow: inset 0 0 0 9999px rgba(0, 0, 0, 0.08);
}

expander-widget > box > title:drop(active) > expander,
expander-widget > box > title:hover > expander {
  box-shadow: inset 0 0 0 9999px rgba(0, 0, 0, 0.08);
}

expander-widget > box > title:active > expander {
  transition-duration: 75ms, 225ms, 0ms, 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-size: 0% 0%;
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

/**
 * Calendar
 */
calendar {
  border-radius: 4px;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

calendar:disabled {
  color: rgba(0, 0, 0, 0.38);
}

calendar > header {
  padding: 4px;
  border-spacing: 4px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

calendar > header > button.image-button {
  padding: 0;
  min-width: 28px;
  min-height: 28px;
  border-radius: 9999px;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
  box-shadow: none;
  background-color: transparent;
}

calendar > header > button.image-button:drop(active), calendar > header > button.image-button:hover {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
}

calendar > header > button.image-button:focus {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.08);
}

calendar > header > button.image-button:active {
  box-shadow: none;
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

calendar > header > button.image-button:disabled {
  color: rgba(0, 0, 0, 0.26);
}

calendar > grid {
  padding: 4px;
  border-spacing: 4px;
}

calendar > grid > label {
  padding: 0;
  min-width: 28px;
  min-height: 28px;
  border-radius: 9999px;
}

calendar > grid > label.day-name,
calendar > grid > label.week-number {
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

calendar > grid > label.day-number:drop(active), calendar > grid > label.day-number:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

calendar > grid > label.day-number:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

calendar > grid > label.day-number:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

calendar > grid > label.day-number.today {
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.6);
}

calendar > grid > label.day-number.other-month {
  color: rgba(0, 0, 0, 0.26);
}

calendar > grid > label.day-number:selected {
  background-color: rgba(25, 103, 210, 0.24);
  box-shadow: inset 0 0 0 1px transparent;
  background-color: rgba(25, 103, 210, 0.24);
}

calendar > grid > label.day-number:selected:drop(active), calendar > grid > label.day-number:selected:hover {
  background-color: rgba(25, 103, 210, 0.3312);
}

calendar > grid > label.day-number:selected:focus {
  background-color: rgba(25, 103, 210, 0.3312);
}

calendar > grid > label.day-number:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

/**
 * Dialogs
 */
window.dialog.message.csd.background {
  min-width: 280px;
  border-radius: 4px;
  background-color: #fff;
}

window.dialog.message > .titlebar {
  min-height: 24px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

window.dialog.message > .titlebar:backdrop {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.6);
}

window.dialog.message > box.dialog-vbox.vertical {
  border-spacing: 20px;
}

window.dialog.message > box.dialog-vbox.vertical > box.vertical > box.horizontal {
  margin: 0 -6px;
}

window.dialog.message label.title {
  font-weight: 500;
  font-size: 15pt;
  letter-spacing: 0.1125pt;
}

window.dialog.message label.title + label {
  color: rgba(0, 0, 0, 0.6);
}

window.dialog.message list,
window.dialog.message .view {
  background-color: transparent;
}

window.dialog.message .dialog-action-area > button:not(:disabled) {
  color: #1967d2;
}

window.dialog.message .dialog-action-area > button:not(:disabled):drop(active), window.dialog.message .dialog-action-area > button:not(:disabled):hover {
  background-color: rgba(25, 103, 210, 0.12);
}

window.dialog.message .dialog-action-area > button:not(:disabled):focus {
  background-color: rgba(25, 103, 210, 0.12);
}

window.dialog.message .dialog-action-area > button:not(:disabled):active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

window.dialog.message .dialog-action-area > button.suggested-action:not(:disabled) {
  background-color: transparent;
}

window.dialog.message .dialog-action-area > button.destructive-action:not(:disabled) {
  background-color: transparent;
  color: #d93025;
}

window.dialog.message .dialog-action-area > button.destructive-action:not(:disabled):drop(active), window.dialog.message .dialog-action-area > button.destructive-action:not(:disabled):hover {
  background-color: rgba(217, 48, 37, 0.12);
}

window.dialog.message .dialog-action-area > button.destructive-action:not(:disabled):focus {
  background-color: rgba(217, 48, 37, 0.12);
}

window.dialog.message .dialog-action-area > button.destructive-action:not(:disabled):active {
  background-image: radial-gradient(circle, rgba(217, 48, 37, 0.16) 10%, transparent 10%);
}

.dialog-action-area {
  padding: 6px;
  border-spacing: 6px;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

filechooser #pathbarbox > stack > box > button {
  border-radius: 9999px;
}

filechooserbutton > button > box {
  border-spacing: 6px;
}

/**
 * Sidebar
 */
.sidebar {
  border-style: none;
}

.sidebar:not(separator):dir(ltr), .sidebar.left:not(separator), .sidebar.left:not(separator):dir(rtl) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
  border-left-style: none;
}

.sidebar:not(separator):dir(rtl), .sidebar.right:not(separator) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
  border-right-style: none;
}

paned .sidebar:dir(rtl):not(:dir(ltr)), paned .sidebar:dir(ltr):not(:dir(rtl)) {
  border-style: none;
}

stacksidebar.sidebar list {
  padding: 4px;
}

stacksidebar.sidebar list.separators:not(.horizontal) > row:not(:first-child) {
  border-top-style: none;
}

stacksidebar.sidebar row {
  min-height: 32px;
  padding: 0 2px;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

stacksidebar.sidebar row:selected {
  background-color: rgba(25, 103, 210, 0.16);
  color: #1967d2;
  background-color: rgba(25, 103, 210, 0.16);
}

stacksidebar.sidebar row:selected:drop(active), stacksidebar.sidebar row:selected:hover {
  background-color: rgba(25, 103, 210, 0.2608);
}

stacksidebar.sidebar row:selected:focus {
  background-color: rgba(25, 103, 210, 0.2608);
}

stacksidebar.sidebar row:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

stacksidebar.sidebar row + row {
  margin-top: 4px;
}

stacksidebar.sidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

/**
 * File chooser
 */
row image.sidebar-icon {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(0, 0, 0, 0.6);
}

row image.sidebar-icon:disabled {
  color: rgba(0, 0, 0, 0.26);
}

placessidebar.sidebar list {
  padding: 4px 0;
}

placessidebar.sidebar list > separator {
  margin: 4px 0;
}

placessidebar.sidebar row {
  min-height: 32px;
  margin: 0 4px;
  padding: 0;
  border-radius: 4px;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

placessidebar.sidebar row > revealer {
  padding: 0 8px;
}

placessidebar.sidebar row:selected {
  background-color: rgba(25, 103, 210, 0.16);
  color: #1967d2;
  background-color: rgba(25, 103, 210, 0.16);
}

placessidebar.sidebar row:selected:drop(active), placessidebar.sidebar row:selected:hover {
  background-color: rgba(25, 103, 210, 0.2608);
}

placessidebar.sidebar row:selected:focus {
  background-color: rgba(25, 103, 210, 0.2608);
}

placessidebar.sidebar row:selected:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

placessidebar.sidebar row:selected image.sidebar-icon {
  color: #1967d2;
}

placessidebar.sidebar row:disabled {
  color: rgba(0, 0, 0, 0.38);
}

placessidebar.sidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar.sidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar.sidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar.sidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar.sidebar row.sidebar-placeholder-row {
  background-color: rgba(0, 0, 0, 0.08);
}

placessidebar.sidebar row.sidebar-new-bookmark-row {
  color: #1967d2;
}

placessidebar.sidebar row.sidebar-new-bookmark-row image.sidebar-icon {
  color: #1967d2;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > box {
  border-spacing: 6px;
}

placesview > actionbar > revealer > box > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

/**
 * Paned
 */
paned > separator {
  background-clip: content-box;
}

paned > separator.wide {
  min-width: 4px;
  min-height: 4px;
  border: 1px solid rgba(0, 0, 0, 0.12);
  background-color: transparent;
}

paned.horizontal > separator:not(.wide) {
  margin: 0 -4px;
  padding: 0 4px;
}

paned.horizontal > separator.wide {
  border-style: none solid;
}

paned.vertical > separator:not(.wide) {
  margin: -4px 0;
  padding: 4px 0;
}

paned.vertical > separator.wide {
  border-style: solid none;
}

/**
 * GtkVideo
 */
video {
  background-color: black;
}

video image.osd {
  min-width: 64px;
  min-height: 64px;
  border-radius: 32px;
  background-color: rgba(0, 0, 0, 0.6);
  color: #fff;
}

video controls.osd {
  padding: 4px;
  background-image: linear-gradient(to bottom, transparent, rgba(0, 0, 0, 0.1) 30%, rgba(0, 0, 0, 0.2) 50%, rgba(0, 0, 0, 0.4));
  color: rgba(255, 255, 255, 0.87);
}

video controls.osd button {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.6);
}

video controls.osd button:drop(active), video controls.osd button:hover {
  background-color: rgba(255, 255, 255, 0.08);
}

video controls.osd button:focus {
  background-color: rgba(255, 255, 255, 0.08);
}

video controls.osd button:active {
  background-image: radial-gradient(circle, rgba(255, 255, 255, 0.12) 10%, transparent 10%);
}

/**
 * GtkInfoBar
 */
infobar > revealer > box {
  padding: 8px;
  border-spacing: 12px;
}

infobar.action:hover > revealer > box {
  background-image: image(rgba(0, 0, 0, 0.08));
}

infobar.info > revealer > box, infobar.question > revealer > box {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

infobar.info > revealer > box button.text-button:not(:disabled), infobar.question > revealer > box button.text-button:not(:disabled) {
  color: #1967d2;
}

infobar.info > revealer > box button.text-button:not(:disabled):drop(active), infobar.info > revealer > box button.text-button:not(:disabled):hover, infobar.question > revealer > box button.text-button:not(:disabled):drop(active), infobar.question > revealer > box button.text-button:not(:disabled):hover {
  background-color: rgba(25, 103, 210, 0.12);
}

infobar.info > revealer > box button.text-button:not(:disabled):focus, infobar.question > revealer > box button.text-button:not(:disabled):focus {
  background-color: rgba(25, 103, 210, 0.12);
}

infobar.info > revealer > box button.text-button:not(:disabled):active, infobar.question > revealer > box button.text-button:not(:disabled):active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

infobar.warning > revealer > box {
  background-color: #f9ab00;
  color: #000;
}

infobar.warning > revealer > box button.flat {
  color: #000;
}

infobar.warning > revealer > box button.flat:drop(active), infobar.warning > revealer > box button.flat:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

infobar.warning > revealer > box button.flat:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

infobar.warning > revealer > box button.flat:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

infobar.warning > revealer > box link {
  color: #000;
}

infobar.error > revealer > box {
  background-color: #d93025;
  color: #fff;
}

infobar.error > revealer > box button.flat {
  color: #fff;
}

infobar.error > revealer > box button.flat:drop(active), infobar.error > revealer > box button.flat:hover {
  background-color: rgba(255, 255, 255, 0.08);
}

infobar.error > revealer > box button.flat:focus {
  background-color: rgba(255, 255, 255, 0.08);
}

infobar.error > revealer > box button.flat:active {
  background-image: radial-gradient(circle, rgba(255, 255, 255, 0.12) 10%, transparent 10%);
}

infobar.error > revealer > box link {
  color: #fff;
}

/**
 * Tooltips
 */
tooltip {
  min-height: 24px;
  padding: 4px 8px;
  border-radius: 4px;
}

tooltip.background {
  background-color: rgba(97, 97, 97, 0.9);
  color: #fff;
}

tooltip:not(.csd) {
  background-color: rgba(97, 97, 97, 0.9);
}

tooltip > box {
  border-spacing: 6px;
}

tooltip .dim-label {
  color: rgba(255, 255, 255, 0.7);
}

/**
 * Color Chooser
 */
colorswatch {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

colorswatch:drop(active), colorswatch.activatable:hover {
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 8px 0 rgba(0, 0, 0, 0.12);
}

colorswatch:disabled {
  opacity: .5;
}

colorswatch.top {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

colorswatch.bottom {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}

colorswatch.dark {
  color: #fff;
}

colorswatch.light {
  color: #000;
}

colorswatch#add-color-button {
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
}

colorswatch#editor-color-sample {
  border-radius: 4px;
}

colorchooser .popover.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 4px;
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #fff;
}

colorchooser .popover.osd:backdrop {
  box-shadow: 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
}

/**
 * Misc
 */
/**
 * Window Decorations
 */
window.csd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 4px 4px 0 0;
  border-radius: 4px;
  box-shadow: 0 8px 10px -5px rgba(0, 0, 0, 0.2), 0 16px 24px 2px rgba(0, 0, 0, 0.14), 0 6px 30px 5px rgba(0, 0, 0, 0.12), 0 16px 24px 2px transparent, 0 6px 30px 5px transparent;
}

window.csd:backdrop {
  box-shadow: 0 2px 4px -1px rgba(0, 0, 0, 0.2), 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), 0 16px 24px 2px transparent, 0 6px 30px 5px transparent;
}

window.ssd {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16);
}

window.solid-csd {
  margin: 0;
  padding: 2px;
  border-radius: 0;
  box-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #f0f0f0;
}

window.solid-csd:backdrop {
  background-color: #ebebeb;
}

window.maximized, window.fullscreen, window.tiled, window.tiled-top, window.tiled-left, window.tiled-right, window.tiled-bottom {
  border-radius: 0;
}

.monospace {
  font-family: monospace;
}

/**
 * Touch Copy & Paste
 */
cursor-handle {
  min-width: 24px;
  min-height: 24px;
  border-radius: 50%;
  background-color: #1967d2;
}

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
  border-top-right-radius: 0;
}

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
  border-top-left-radius: 0;
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  margin-top: 6px;
  transform: rotate(45deg);
}

shortcuts-section {
  margin: 20px;
}

.shortcuts-search-results {
  margin: 20px;
  border-spacing: 24px;
}

shortcut {
  border-spacing: 6px;
}

shortcut > .keycap {
  min-width: 12px;
  min-height: 28px;
  padding-left: 8px;
  padding-right: 8px;
  border-radius: 4px;
  box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.2), 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
  background-color: #fff;
  color: rgba(0, 0, 0, 0.87);
  font-size: smaller;
}

stackswitcher > button.text-button {
  min-width: 100px;
}

stackswitcher.circular {
  border-spacing: 12px;
}

stackswitcher.circular > button.circular {
  min-width: 36px;
  min-height: 36px;
  padding: 0;
}

/**
 * App Icons
 */
/**
 * Emoji
 */
popover.emoji-picker > contents {
  padding: 0;
}

popover.emoji-picker > contents emoji {
  min-width: 3em;
  min-height: 3em;
  border-radius: 4px;
}

popover.emoji-picker > contents emoji:drop(active), popover.emoji-picker > contents emoji:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-picker > contents emoji:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-picker > contents emoji:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

.emoji-searchbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.emoji-searchbar > entry.search {
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

.emoji-toolbar {
  padding: 4px;
  border-spacing: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.emoji-toolbar > button.emoji-section:checked {
  background-color: rgba(25, 103, 210, 0.16);
  color: #1967d2;
  background-color: rgba(25, 103, 210, 0.16);
}

.emoji-toolbar > button.emoji-section:checked:drop(active), .emoji-toolbar > button.emoji-section:checked:hover {
  background-color: rgba(25, 103, 210, 0.2608);
}

.emoji-toolbar > button.emoji-section:checked:focus {
  background-color: rgba(25, 103, 210, 0.2608);
}

.emoji-toolbar > button.emoji-section:checked:active {
  background-image: radial-gradient(circle, rgba(25, 103, 210, 0.16) 10%, transparent 10%);
}

popover.emoji-completion > contents {
  padding: 8px 0;
}

popover.emoji-completion > contents emoji-completion-row {
  min-height: 32px;
  padding: 0 8px;
}

popover.emoji-completion > contents emoji-completion-row:drop(active), popover.emoji-completion > contents emoji-completion-row:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-completion > contents emoji-completion-row:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-completion > contents emoji-completion-row:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

popover.emoji-completion > contents emoji-completion-row > box {
  border-spacing: 8px;
}

popover.emoji-completion > contents emoji {
  border-radius: 4px;
}

popover.emoji-completion > contents emoji:drop(active), popover.emoji-completion > contents emoji:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-completion > contents emoji:focus {
  background-color: rgba(0, 0, 0, 0.08);
}

popover.emoji-completion > contents emoji:active {
  background-image: radial-gradient(circle, rgba(0, 0, 0, 0.12) 10%, transparent 10%);
}

popover.entry-completion > contents {
  padding: 0;
}

popover.entry-completion > contents treeview.view {
  min-height: 32px;
  padding: 8px 0;
}

popover.entry-completion > contents treeview.view > .cell {
  padding: 0 4px;
}

popover.entry-completion > contents treeview.view > .cell:selected:hover {
  background-color: rgba(0, 0, 0, 0.08);
}

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color rgba(0, 0, 0, 0.87);
/*
text color for entries, views and content in general */
@define-color theme_text_color rgba(0, 0, 0, 0.87);
/*
widget base background color */
@define-color theme_bg_color #f9f9f9;
/*
text widgets and the like base background color */
@define-color theme_base_color #fff;
/*
base background color of selections */
@define-color theme_selected_bg_color #1967d2;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #fff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #f9f9f9;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color rgba(0, 0, 0, 0.38);
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #fff;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color rgba(0, 0, 0, 0.87);
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color rgba(0, 0, 0, 0.87);
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #f9f9f9;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #fff;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #1967d2;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #fff;
/*
insensitive color on backdrop windows */
@define-color unfocused_insensitive_color rgba(0, 0, 0, 0.38);
/*
widgets main borders color */
@define-color borders rgba(0, 0, 0, 0.12);
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders rgba(0, 0, 0, 0.12);
/*
these are pretty self explicative */
@define-color warning_color #f9ab00;
@define-color error_color #d93025;
@define-color success_color #1e8e3e;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title rgba(0, 0, 0, 0.87);
@define-color wm_unfocused_title rgba(0, 0, 0, 0.6);
@define-color wm_highlight rgba(255, 255, 255, 0.4);
@define-color wm_bg #f0f0f0;
@define-color wm_unfocused_bg #ebebeb;
@define-color xfwm4_title #1f1f1f;
@define-color xfwm4_unfocused_title #5e5e5e;
/* content view background such as thumbnails view in Photos or Boxes */
@define-color content_view_bg #f9f9f9;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #f9f9f9;
/* placeholder for entries */
@define-color placeholder_text_color #666666;
